@@ -62,22 +62,26 @@ class prequest(Xpath):
         self.retry_interval = retry_interval
         self.meta_ = meta
         if headers and isinstance(headers, dict):
+            if headers.get('user-agent') or headers.get('User-Agent'):
+                header = {}
             header.update(headers)
+            print(header)
         while True:
             try:
                 self.response = requests.request(
                     url=url, headers=header, timeout=timeout, method=self.method, *args, **kwargs)
                 self.response.encoding = encoding
-                if self.response.status_code == 200:
+                if self.response.ok:
                     return self
                 else:
                     raise Exception(f'Respider {self.retry_interval}s')
             except Exception as e:
                 logging.error('%s [ERRORS] [Url] %s [Msg] %s' % (self.current_time, url, e))
-                logging.info('[Retry Url] %s [Interval] %ss' % (url, retry_interval))
+                if settion.retry:
+                    logging.info('[Retry Url] %s [Interval] %ss' % (url, retry_interval))
                 retry_time -= 1
                 if retry_time <= 0 or settion.retry is False:
-                    self.response.status_code = 405
+                    self.response.status_code = 410 if not self.response.status_code else self.response.status_code
                     return self
                 time.sleep(retry_interval)
 
@@ -110,7 +114,7 @@ class prequest(Xpath):
         return self.response.headers
 
     @property
-    def get_len(self):
+    def len(self):
         return len(self.response.text)
 
     @property
@@ -120,9 +124,6 @@ class prequest(Xpath):
     def xpath(self, xpath_str, **kwargs):
         return Xpath(self.response.text).xpath(xpath_str, **kwargs)
 
-    def xxpath(self, xpath_str, **kwargs):
-        return Xpath(self.response.text).xxpath(xpath_str, **kwargs)
-
     @property
     def ok(self):
         return self.response.ok
@@ -135,4 +136,4 @@ class prequest(Xpath):
         self.response.close()
 
     def __str__(self) -> str:
-        return f"<{type(self).__name__} code={self.code} len={self.get_len}>"
+        return f"<Response Code={self.code} Len={self.len}>"
