@@ -1,11 +1,10 @@
 import os
 
-code_str = """
-from PrSpider import PrSpiders
+code_str = """from PrSpider import PrSpiders
 
 
 class Spider(PrSpiders):
-    start_urls = 'http://example.com'
+    start_urls = 'https://www.runoob.com'
 
     def parse(self, response):
         # print(response.text)
